//
//  MLKWideAngleView.m
//  MLKWideAngleView
//
//  Created by Michael Kral on 1/30/13.
//  Copyright (c) 2013 Michael Kral. All rights reserved.
//

#import "MLKWideAngleView.h"

@implementation MLKWideAngleView

@synthesize image, contentMode, focusPoint = _focusPoint;

-(id)initWithFrame:(CGRect)frame image:(UIImage *)anImage focusPoint:(ImageFocusPoint)aFocusPoint contentMode:(UIViewContentMode)aContentMode
{
    if(self = [super initWithFrame:frame]){
        
        self.focusPoint = aFocusPoint;
        self.image = anImage;
        self.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;
        _imageView = [[UIImageView alloc] initWithFrame:self.bounds];
        [_imageView setImage:anImage];
        [_imageView setContentMode:aContentMode];
        
        [self addSubview:_imageView];
        
    }
    return self;
}
/*
//Image
-(UIImage*)image
{
    return _imageView.image;
}

-(void)setImage:(UIImage *)_image{
    _imageView.image = _image;
    [self setNeedsLayout];
}

//Content Mode
-(UIViewContentMode)contentMode{
    return _imageView.contentMode;
}
-(void)setContentMode:(UIViewContentMode)_contentMode{
    _imageView.contentMode = _contentMode;
    [self setNeedsLayout];
}

//FocusPoint
-(ImageFocusPoint)focusPoint{
    return _focusPoint;
}
-(void)setFocusPoint:(ImageFocusPoint)focusPoint{
    self.focusPoint = focusPoint;
    [self setNeedsLayout];
}*/

-(void)layoutSubviews{
    [super layoutSubviews];
    
    CGFloat portraitImageViewXOrigin = 0;
    CGFloat portraitImageViewYOrigin = 0;
    
    CGFloat landscapeImageViewXOrigin = 0;
    CGFloat landscapeImageViewYOrigin = 0;
    
    CGFloat imageViewWidth = self.image.size.width;
    CGFloat imageViewHeight = self.image.size.height;
    
    switch (self.focusPoint) {
        case bottomLeft:
            landscapeImageViewXOrigin = 0;
            landscapeImageViewYOrigin = -(imageViewHeight - CGRectGetHeight(self.bounds));
            portraitImageViewXOrigin = 0;
            portraitImageViewYOrigin = - (imageViewHeight - CGRectGetHeight(self.bounds));
            break;
        case bottomCenter:
            portraitImageViewXOrigin = - (imageViewWidth - CGRectGetWidth(self.bounds)) / 2;
            portraitImageViewYOrigin =  -(imageViewHeight - CGRectGetHeight(self.bounds));
            landscapeImageViewYOrigin = - (imageViewHeight - CGRectGetHeight(self.bounds));
            landscapeImageViewXOrigin = - (imageViewWidth - CGRectGetWidth(self.bounds)) / 2;
            break;
        case bottomRight:
            portraitImageViewXOrigin = - (imageViewWidth - CGRectGetWidth(self.bounds));
            portraitImageViewYOrigin =  - (imageViewHeight - CGRectGetHeight(self.bounds));
            landscapeImageViewXOrigin = - (imageViewWidth - CGRectGetWidth(self.bounds));
            landscapeImageViewYOrigin = - (imageViewHeight - CGRectGetHeight(self.bounds));
            break;
        default:
            break;
    }
    
    if(CGRectGetHeight(self.bounds) > CGRectGetWidth(self.bounds)){
        //Portrait Mode
        [_imageView setFrame:CGRectMake(portraitImageViewXOrigin, portraitImageViewYOrigin, imageViewWidth, imageViewHeight)];
    }else{
        //LandscapeMode
        [_imageView setFrame:CGRectMake(landscapeImageViewXOrigin, landscapeImageViewYOrigin, imageViewWidth, imageViewHeight)];
    }
    
    
    
}

- (void)setFrame:(CGRect)frame
{
    [super setFrame:frame];
    [self setNeedsLayout];
}

@end
